#include <EEPROM.h>

//  Spectro_ledControl
//
//  Continuously Read the Current Value from the OPT101P on A0 Input and Display in Serial Monitor 
//
//  Poll the Serial Input and Toggle the Specified LED (CR Based)
//
//  mykepredko.mimetics.ca

int    serialByte  = 0;           //  For incoming serial data
int    commandByte = 0;           //  Command to Execute
int    x;                         //  Stored Value for ADC Read
String ADCvalue;
int    ledPins[]   = {              //  LED IO Pins
                       2          //  Blue
                    ,  4          //  Green
                    ,  6          //  Amber
                    ,  8          //  Red
                    , 10          //  IR 880nm
                    , 12          //  IR 940nm
                     };
int    ledValues[] = {            //  LED IO Pins
                       0          //  Blue
                    ,  0          //  Green
                    ,  0          //  Amber
                    ,  0          //  Red
                    ,  0          //  IR 880nm
                    ,  0          //  IR 940nm
                     };


void setup() {

    Serial.begin(9600);           //  Setup Serial library at 9600 bps
    
    pinMode(A0, INPUT);           //  Setup OTPT101P Analog Input    
    
    pinMode(ledPins[0],  OUTPUT);  digitalWrite(ledPins[0],  LOW);  //  Setup the LED IO Pins
    pinMode(ledPins[1],  OUTPUT);  digitalWrite(ledPins[1],  LOW);  
    pinMode(ledPins[2],  OUTPUT);  digitalWrite(ledPins[2],  LOW);  
    pinMode(ledPins[3],  OUTPUT);  digitalWrite(ledPins[3],  LOW);  
    pinMode(ledPins[4],  OUTPUT);  digitalWrite(ledPins[4],  LOW);  
    pinMode(ledPins[5],  OUTPUT);  digitalWrite(ledPins[5],  LOW);  
       
    Serial.write(27);  Serial.print("[2J");             //  VT100 Clear Screen
    Serial.write(27);  Serial.print("[H");              //  VT100 Move to Top Left Corner

}


void loop() {

    if (0 < Serial.available()) {
        serialByte = Serial.read();
        if ((0x0D == serialByte) && (0 != commandByte)) {       //  Carriage Return
            commandByte -= '0';                                 //  Get LED Index
            if (0 == ledValues[commandByte]) {
                digitalWrite(ledPins[commandByte], HIGH);
                ledValues[commandByte] = 1;
            }
            else {
                digitalWrite(ledPins[commandByte], LOW);
                ledValues[commandByte] = 0;
            }
            commandByte = 0;
        }
        else if (0x08 == serialByte) {                          //  Backspace
            commandByte = 0;                                    //  Clear the active Command
        }
        else if (('0' <= serialByte) && ('5' >= serialByte)) {  //  LED Specifier
            if (0 == commandByte) {
                commandByte = serialByte;  
            }
        }
    }
  
    for (ADCvalue = String(analogRead(A0)); 4 > ADCvalue.length(); ADCvalue = String(" " + ADCvalue)) {
    }
    Serial.write(13);  Serial.print("Analog value: ");  Serial.print(ADCvalue);  
    delay(100);
}
